summaryrefslogtreecommitdiff
path: root/vpath.c
diff options
context:
space:
mode:
authorEli Zaretskii <eliz@gnu.org>2009-12-11 09:47:41 +0000
committerEli Zaretskii <eliz@gnu.org>2009-12-11 09:47:41 +0000
commitf4d9937274de3960f3af7356e1581163bafb93c3 (patch)
treed589490e57b931b10f8bd71c315d821f8d9bea27 /vpath.c
parentb6f45ddc5301b7d7f6472e38a475716ff1414186 (diff)
downloadgunmake-f4d9937274de3960f3af7356e1581163bafb93c3.tar.gz
(construct_vpath_list): Correct the argument names in the commentary.
Diffstat (limited to 'vpath.c')
-rw-r--r--vpath.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/vpath.c b/vpath.c
index e9cd691..4b5ff2c 100644
--- a/vpath.c
+++ b/vpath.c
@@ -137,7 +137,7 @@ build_vpath_lists ()
}
}
/* Construct the VPATH listing for the pattern and searchpath given.
This function is called to generate selective VPATH lists and also for
the general VPATH list (which is in fact just a selective VPATH that
@@ -145,9 +145,9 @@ build_vpath_lists ()
linked list of all selective VPATH lists or in the GENERAL_VPATH
variable.
- If SEARCHPATH is nil, remove all previous listings with the same
+ If DIRPATH is nil, remove all previous listings with the same
pattern. If PATTERN is nil, remove all VPATH listings. Existing
- and readable directories that are not "." given in the searchpath
+ and readable directories that are not "." given in the DIRPATH
separated by the path element separator (defined in make.h) are
loaded into the directory hash table if they are not there already
and put in the VPATH searchpath for the given pattern with trailing
@@ -137,7 +137,7 @@ build_vpath_lists ()
}
}
-/* Construct the VPATH listing for the pattern and searchpath given.
+/* Construct the VPATH listing for the PATTERN and DIRPATH given.
This function is called to generate selective VPATH lists and also for
the general VPATH list (which is in fact just a selective VPATH that